import { Component, OnInit, ViewChild, ViewEncapsulation } from '@angular/core';
import { DiagramComponent } from '@syncfusion/ej2-ng-diagrams';
import {
    NodeModel, ConnectorModel, DiagramTools, Diagram, DataBinding, ComplexHierarchicalTree,
    SnapConstraints, SnapSettingsModel, LayoutModel, LayoutOrientation
} from "@syncfusion/ej2-diagrams";
import { DataManager } from "@syncfusion/ej2-data";
import * as Data from './diagram-data.json';
Diagram.Inject(DataBinding, ComplexHierarchicalTree);

export interface DataInfo {
    [key: string]: string;
}


export interface EmployeeInfo {
  Name: string;
  Role: string;
}

@Component({
  selector: 'sync-fusion-diagram',
  templateUrl: './sync-fusion-diagram.component.html',
  styleUrls: ['./sync-fusion-diagram.component.css'],
  encapsulation: ViewEncapsulation.None
})
export class SyncFusionDiagramComponent implements OnInit {
  //@ViewChild("diagram") public layout: LayoutModel;
    @ViewChild('diagram')
    public diagram: DiagramComponent;
	
     public layout: LayoutModel = {
        type: 'ComplexHierarchicalTree',
        horizontalSpacing: 40, 
		verticalSpacing: 40, 
		orientation: 'LeftToRight',
        margin: { left: 10, right: 10, top: 50, bottom: 50 }
    };
	/* other orientations: 'TopToBottom', */
  
  /* public dataSourceSettings: DataSourceModel; */
  
  public dataSourceSettings: Object = {
	id: 'Name', 
	parentId: 'ReportingPerson',
	dataManager: new DataManager((Data as any).multiParentData),
	//binds the external data with node
	doBinding: (nodeModel: NodeModel, data: DataInfo, diagram: Diagram) => {
		/* tslint:disable:no-string-literal */
		nodeModel.style = { 
		fill: data['fillColor'], 
		strokeWidth: 1, 
		strokeColor: this.getBorderColour(data['Role']) };
	}	  
  };
  
  public getBorderColour(role: string): string {
	  switch (role) {
		  case "Director": return "red";
		  case "Manager": return "blue";
		  default: return "green";
	  }
  }
  
  /*
  public data: Object[] = [
    {
      Name: "Elizabeth",
      Role: "Director"
    },
    {
      Name: "Christina",
      ReportingPerson: "Elizabeth",
      Role: "Manager"
    },
    {
      Name: "Yoshi",
      ReportingPerson: "Christina",
      Role: "Lead"
    },
    {
      Name: "Philip",
      ReportingPerson: "Christina",
      Role: "Lead"
    },
    {
      Name: "Yang",
      ReportingPerson: "Elizabeth",
      Role: "Manager"
    },
    {
      Name: "Roland",
      ReportingPerson: "Yang",
      Role: "Lead"
    },
    {
      Name: "Yvonne",
      ReportingPerson: "Yang",
      Role: "Lead"
    }
  ];*/

  public nodeDefaults(node: NodeModel): NodeModel {
	node.width = 100; 
	node.height = 40;
	//Initialize shape
	node.shape = { type: 'Basic', shape: 'Rectangle', cornerRadius: 0 };
    node.annotations = [
      { content: (node.data as EmployeeInfo).Name, style: { color: "black" } }
    ];
	return node;
	  /*
    let codes: Object = {
      Director: "rgb(0, 139,139)",
      Manager: "rgb(30, 30,113)",
      Lead: "rgb(0, 100,0)"
    };
    node.width = 70;
    node.height = 30;
    node.style.fill = codes[(node.data as EmployeeInfo).Role];
    return node;
	*/
  }

  public connectorDefaults(connector: ConnectorModel): ConnectorModel {
    connector.type = "Orthogonal";
    connector.cornerRadius = 0;
	connector.targetDecorator.height = 7;
	connector.targetDecorator.width = 7;
	connector.style.strokeColor = '#6d6d6d';
    return connector;
  }
  
  public tool: DiagramTools = DiagramTools.ZoomPan;

  public snapSettings: SnapSettingsModel = { constraints: SnapConstraints.None };
  
  constructor() { }

  ngOnInit() {
	  /*
    this.layout = {
      type: "OrganizationalChart"
    };
    this.dataSourceSettings = {
      id: "Name",
      parentId: "ReportingPerson",
      dataManager: new DataManager(this.data as JSON[])
    };*/
  }

}
